@@ -1,6 +1,6 @@
 from django.shortcuts import get_object_or_404
 from django.core.files.uploadedfile import InMemoryUploadedFile
-
+from django.core.cache import cache
 from celery import task
 import StringIO
 
@@ -11,5 +11,7 @@ def async_save(data, file, type, id):
     image = InMemoryUploadedFile(img, *file)
     instance.__dict__[file[0]] = image
     instance.save()
+    #invalidate the cache
+    cache.clear()
     
     
\ No newline at end of file
